# 系统说明

- 基于 Spring Boot、SpringCloud、Oauth2 的 **后端综合系统**
- 采用Nacos作为服务注册中心和配置中心
- 用户采用SpringSecurity Oauth2的客户端认证、授权
- 使用redis-cluster做缓存
- 使用rabbitMq做消息队列
- 使用openFeign实现服务之间的调用
- 使用mysql8+做数据库



## 核心依赖

|   依赖   |   版本   |
| :-----------: | :-----------: |
| SpringBoot  | 2.3.2.RELEASE |
| SrpringCloud | Hoxton.SR9  |
| Mybatis Plus |   3.5.2   |



## 模块说明

```
pdf_office_back_end
├── pdf-office-gateway            // 网关模块 [8080]
├── pdf-office-auth               // 认证中心 [9527]
├── pdf-office-common             // 公用模块
│ └── pdf-office-common-file	  // 文件模块
│ └── pdf-office-common-core      // 核心模块
│ └── pdf-office-common-api       // api模块
│ └── pdf-office-common-security  // 安全模块
│ └── pdf-office-common-feign     // feign模块
│ └── pdf-office-common-redis     // redis 模块
│ └── pdf-office-common-rabbitmq  // rabbitmq 模块
│ └── pdf-office-common-mybatis   // mybatis 扩展封装
├── pdf-office-mail               // 邮件中心模块 [7000]
├── pdf-office-generate           // 代码生成模块 [9183]
├── pdf-office-payment            // 支付中心服务 [8000]
├── pdf-office-system             // 运营系统模块 [9000]
├── pdf-office-pdf-website        // 官网系统模块 [9010]
├── pdf-office-app                // APP系统模块 [9020]
├── pdf-office-job                // 任务模块 [10000]
```

## 系统流程
![系统流程](img.png)
[原图](https://www.processon.com/mindmap/63b7ee62cd1c781ac5d8ad51)

## 项目环境

- Java8+
- MySQL8.0+
- Redis7.0+
- Nacos2.0.2
- RabbitMQ3.10.0

## 服务启动
```
pdf-office-auth         必须
pdf-office-gateway      必须
```

1. 先本地下载Nacos并启动，或直接用测试机上的Nacos(地址：http://106.55.99.175:8848/nacos，账号：nacos，密码：nacos)
2. 启动pdf-office-auth，客户端认证请求token：http://localhost:9527/oauth/token

## 目前可开发模块
- pdf-office-gateway
- pdf-office-auth
- pdf-office-common
- pdf-office-mail
- pdf-office-generate
- pdf-office-payment
## 后续待开发
需确认[方案](https://docs.google.com/document/d/1jE7Z2lwUUyHtqYhvVsZjOk35cGgFCdgIQM22c__XxnY/edit#)


## Nacos
> 仅用于本地测试版本
- IP：106.55.99.175
- 端口：18848
- 用户名：nacos
- 密码：nacos

## Redis
- IP：
- 端口：33465
- 密码：1qazZAQ!2

## RabbitMQ
- IP：
- 端口：15672
- 用户名：admin
- 密码：Admin@123!

