package cn.kdan.cloud.pdf.office.common.config;

import cn.kdan.cloud.pdf.office.common.constant.RabbitMqConstant;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Binding;
import org.springframework.amqp.core.Exchange;
import org.springframework.amqp.core.Queue;
import org.springframework.amqp.core.TopicExchange;
import org.springframework.amqp.rabbit.annotation.EnableRabbit;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.annotation.PostConstruct;

/**
 * @author ComPDFKit-WPH 2023/1/11
 * <p>
 * RabbitMqConfig
 */
@Configuration
@RequiredArgsConstructor
@Slf4j
@EnableRabbit
public class RabbitMqConfig {

    private final RabbitTemplate rabbitTemplate;

    /**
     * 发送回调
     */
    @PostConstruct
    public void publisherConfirm() {
        // 消息抵达服务器确认回调，correlationData：当前消息唯一关联数据（消息的唯一id）,ack：消息是否抵达服务器，cause：失败的原因
        rabbitTemplate.setConfirmCallback(
                (correlationData, ack, cause) -> {
                    log.info("发送成功，correlationData -> {}, ack -> {}, cause -> {}", correlationData, ack, cause);
                }
        );

        // 消息到队列的确认回调（当消息未抵达到队列时才会回调），message：当前发送的消息，replyCode：回复的状态码，replyText：回复的信息，exchange：交换机，routingKey：路由键
        rabbitTemplate.setReturnCallback(
                (message, replyCode, replyText, exchange, routingKey) -> {
                    log.info("发送失败，message -> {}, replyCode -> {}, replyText -> {}, exchange -> {}, routingKey -> {}", message, replyCode, replyText, exchange, routingKey);
                }
        );
    }


    // 交换机配置
    /* email交换机 */
    @Bean
    public Exchange emailExchange() {
        return new TopicExchange(RabbitMqConstant.EMAIL_EXCHANGE, true, false);
    }

    // 普通队列配置
    /* 发送email队列 */
    @Bean
    public Queue sendEmailQueue() {
        return new Queue(RabbitMqConstant.EMAIL_SEND_QUEUE, true, false, false);
    }

    // 死信队列配置

    // 路由绑定配置
    /* 发送email路由绑定 */
    @Bean
    public Binding officeConvertBinding() {
        return new Binding(RabbitMqConstant.EMAIL_SEND_QUEUE,
                Binding.DestinationType.QUEUE,
                RabbitMqConstant.EMAIL_EXCHANGE,
                RabbitMqConstant.EMAIL_SEND_ROUTING_KEY, null);
    }

}
