package cn.kdan.cloud.pdf.office.sso.config.oauth;

import cn.kdan.cloud.pdf.office.sso.constant.AuthConstant;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.oauth2.common.exceptions.InvalidTokenException;
import org.springframework.security.web.AuthenticationEntryPoint;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

public class AuthExceptionEntryPoint implements AuthenticationEntryPoint {
    /**
     * 处理token过期的返回内容
     *
     * @throws IOException
     * @throws ServletException
     */
    @Override
    public void commence(HttpServletRequest request, HttpServletResponse response, AuthenticationException authException) throws IOException, ServletException {
        Map<String, Object> map = new HashMap<>(7);
        Throwable cause = authException.getCause();
        if (cause instanceof InvalidTokenException) {
            map.put("code", AuthConstant.EXCEPTION_CODE_TOKEN_IS_INVALID);
            map.put("msg", AuthConstant.EXCEPTION_MSG_TOKEN_IS_INVALID);
        } else {
            map.put("code", AuthConstant.EXCEPTION_CODE_USER_NOT_LOGIN);
            map.put("msg", AuthConstant.EXCEPTION_MSG_USER_NOT_LOGIN);
        }
        map.put("data", authException.getMessage());
        map.put("path", request.getServletPath());
        map.put("timestamp", String.valueOf(System.currentTimeMillis()));
        response.setContentType("application/json");
        response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
        try {
            ObjectMapper mapper = new ObjectMapper();
            mapper.writeValue(response.getOutputStream(), map);
        } catch (Exception e) {
            throw new ServletException();
        }
    }
}
