package cn.kdan.cloud.pdf.office.sso.controller;

import cn.kdan.cloud.pdf.office.sso.constant.AuthConstant;
import cn.kdan.cloud.pdf.office.sso.enums.ImageCodeTypeEnum;
import cn.kdan.cloud.pdf.office.sso.service.AuthService;
import cn.kdan.cloud.pdf.office.sso.utils.ImageCodeUtils;
import cn.kdan.cloud.pdf.office.common.constant.CommonConstant;
import cn.kdan.cloud.pdf.office.common.exception.BackendRuntimeException;
import cn.kdan.cloud.pdf.office.common.pojo.CustomUserDetails;
import cn.kdan.cloud.pdf.office.common.pojo.ResultMap;
import cn.kdan.cloud.pdf.office.common.vo.TokenVO;
import org.apache.commons.lang.StringUtils;
import org.apache.http.entity.ContentType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.imageio.ImageIO;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.security.Principal;
import java.util.Map;

@Controller
@RequestMapping("/auth")
public class AuthController {

    private final AuthService authService;

    @Autowired
    public AuthController(AuthService authService) {
        this.authService = authService;
    }


    /**
     * @param clientId
     * @param principal
     * @param request
     * @Description: 获取授权码，登陆时调用
     * @Return: com.wondersgroup.cloud.cmp.common.pojo.ResultMap<java.lang.String>
     * @Date: 2021/2/10 10:31
     */
    @GetMapping("/getAuthorizeCode")
    @ResponseBody
    public ResultMap<String> authorize(@RequestParam String clientId, Principal principal, HttpServletRequest request) {
        String code = authService.getAuthorizeCode(getUserId(principal), clientId, request);
        if (StringUtils.isNotEmpty(code)) {
            return new ResultMap<>(CommonConstant.SUCCESS, AuthConstant.GET_AUTHORIZE_CODE_SUCCESS, code);
        } else {
            return new ResultMap<>(CommonConstant.ERROR, AuthConstant.EXCEPTION_MSG_GET_CODE_FAIL);
        }
    }

    /**
     * @param clientId
     * @param code
     * @param request
     * @Description: 获取token  登陆时调用
     * @Date: 2021/2/10 10:32
     */
    @GetMapping("/getToken")
    @ResponseBody
    public ResultMap<TokenVO> getToken(@RequestParam String clientId, @RequestParam String code, HttpServletRequest request) {
        TokenVO tokenVO = authService.getToken(code, clientId, request);
        if (tokenVO == null) {
            return new ResultMap<>(AuthConstant.EXCEPTION_CODE_GET_TOKEN_FAIL, AuthConstant.EXCEPTION_MSG_GET_TOKEN_FAIL);
        } else {
            return new ResultMap<>(CommonConstant.SUCCESS, CommonConstant.RESULT_SUCCESS, tokenVO);
        }
    }


    @GetMapping("/emailLogin")
    @ResponseBody
    public ResultMap<TokenVO> getToken(@RequestParam String email, @RequestParam String code, @RequestParam String appId,@RequestParam String platformType,@RequestParam String clientId, HttpServletRequest request) {
        return new ResultMap<>(CommonConstant.SUCCESS, CommonConstant.RESULT_SUCCESS, authService.emailLogin(email,code,appId,platformType,clientId,request));
    }


    private String getUserId(Principal principal) {
        if (principal instanceof UsernamePasswordAuthenticationToken) {
            return ((CustomUserDetails) (((UsernamePasswordAuthenticationToken) principal).getPrincipal())).getId();
        }
        throw new BackendRuntimeException(CommonConstant.EXCEPTION_MSG_LOGIN_USER_NOT_FOUND);
    }


}
