package cn.kdan.cloud.pdf.office.sso.filter;

import cn.kdan.cloud.pdf.office.common.utils.JsonUtils;
import cn.kdan.cloud.pdf.office.sso.constant.AuthConstant;
import cn.kdan.cloud.pdf.office.sso.enums.ImageCodeTypeEnum;
import cn.kdan.cloud.pdf.office.common.pojo.ResultMap;
import cn.kdan.cloud.pdf.office.common.utils.RedisUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.web.authentication.AbstractAuthenticationProcessingFilter;
import org.springframework.security.web.authentication.SimpleUrlAuthenticationFailureHandler;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

public class LoginAuthenticationProcessingFilter extends AbstractAuthenticationProcessingFilter {

    //拦截的url
    private String processUrl;

    private RedisUtils<String,String> redisUtils;

    @Autowired
    public LoginAuthenticationProcessingFilter(String defaultFilterProcessesUrl, String failureUrl,RedisUtils<String,String> redisUtils) {
        super(defaultFilterProcessesUrl);
        this.processUrl = defaultFilterProcessesUrl;
        this.redisUtils = redisUtils;
        setAuthenticationFailureHandler(new SimpleUrlAuthenticationFailureHandler(failureUrl));
    }

    @Override
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
        response.setContentType("application/json;charset=UTF-8");

        HttpServletRequest req = (HttpServletRequest) request;
        if(processUrl.equals(req.getServletPath()) && "POST".equalsIgnoreCase(req.getMethod())){
            String sessionId = req.getSession().getId();
            //获取图形验证码
            String code = req.getParameter("code");
            if(!isImageCodeValid(sessionId, ImageCodeTypeEnum.LOGIN, code)){
                PrintWriter writer = response.getWriter();
                writer.write(JsonUtils.getJsonString(new ResultMap(AuthConstant.EXCEPTION_CODE_IMAGE_CODE_ERROR, AuthConstant.EXCEPTION_MSG_IMAGE_CODE_ERROR)));
                writer.flush();
                writer.close();
                return ;
            }
        }
        chain.doFilter(request, response);
    }

    @Override
    public Authentication attemptAuthentication(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse)
            throws AuthenticationException, IOException, ServletException {
        return null;
    }

    private boolean isImageCodeValid(String sessionId, ImageCodeTypeEnum type, String code) {
        String redisCode = redisUtils.hget(AuthConstant.SESSION_ + sessionId, type.value());
        redisUtils.hdel(AuthConstant.SESSION_ + sessionId, type.value());
        return !StringUtils.isEmpty(code) && code.equalsIgnoreCase(redisCode);
    }
}
